@@ -7,7 +7,7 @@ from bzrlib import mutabletree
 
 version_info = 1,0
 
-TRAILING = re.compile('\s+\n')
+TRAILING = re.compile(' +\n')
 
 
 def fix(tree, fid):
